# ScanHeadsman
## Description
Tool to extract header information from Thermo RAW files

## Requirements
Requires **.NET 4.5** or later and **Themo MS File Reader** to be installed in the system. You can download **.NET** from Microsoft [Download Center](https://www.microsoft.com/en-us/download/details.aspx?id=30653), however, it is preinstalled in all modern versions of Windows. **MS File Reader** can be downloaded from [Thermo FlexNet website](https://thermo.flexnetoperations.com/). You have to register and search for *MS File Reader*. The software was tested with version **3.1.5.0** and should work with other versions as well

##Usage
Just invoke it from the console with the following arguments.

`ScanHeadsan.exe [--noMS] [--methods:Text|XML|CSV|] [Path] [Output filename]`

All arguments are optional.

By default (i.e. no arguments provided) all **RAW** files in the current folder will be processed.

If the provided path is a directory, all **RAW** files in that folder will be processed, if it is a single **RAW** file it will be processed individually.

Extracted information is written in a **CSV**-formatted (commas as separators, ASCII encoded) text file. By default the name of the file is the same as the name of **RAW** file with the extension changed to **.txt** (i.e. *somerawfile.raw* becomes *somerawfile.txt*). You can override the default name of the export file by providing _output filename_ path (will work only for single **RAW** file input).

You can use optional argument `--noMS` to suppress output of MS data (m/z values and intensities), otherwise they will appear in the output file as two additional columns of space separated float numbers (centroided data is used). **WARNING** expect really large csv file if it contains MS data.

You can use optional argument `--methods` to extract method information.

`methods` support additinal modifiers, that are provieded after a semicolon, i.e. **--methods:MODIFIER** The list of modifiers is below

* `text`, no modifier or default - **--methods:text** or **--methods** - Methods exported in the plain text file. The text file is Unicode-encoded and created with the same filename and location as the **RAW** file with the extension changed to **methods.txt** (i.e. *somerawfile.raw* becomes *somerawfile.methods.txt*).
* `XML` - **--methods:XML** - **ONLY** first MS methods is exported in the XML formatted file. **ONLY TNG-Calcium** methods are supported, i.e. Fusion series. The XML file is Unicode-encoded and created with the same filename and location as the **RAW** file with the extension changed to **method.xml** (i.e. *somerawfile.raw* becomes *somerawfile.method.xml*).
* `CSV` - **--methods:CSV** - **ONLY** MS experiments in the first MS methods are exported in the CSV formatted file. **ONLY TNG-Calcium** methods are supported, i.e. Fusion series. The CSV file is ASCII-encoded, with commas as column separators and created with the same filename and location as the **RAW** file with the extension changed to **experiments.csv** (i.e. *somerawfile.raw* becomes *somerawfile.experiments.csv*).

Any existing files will be overwritten silently.

##Examples

`ScanHeadsman.exe`

Process all **RAW** files in the current folder

`ScanHeadsman.exe D:\RawData\OpearationY`

Process all **RAW** files in *D:\RawData\OperationY* with MS data included

`ScanHeadsman.exe D:\RawData\OperationY\storageFacility.raw`

Process *D:\RawData\OperationY\storageFacility.raw* and save the results in *D:\RawData\OperationY\storageFacility.txt* with MS data included

`ScanHeadsman.exe D:\RawData\OperationY\storageFacility.raw --noMS`

Process *D:\RawData\OperationY\storageFacility.raw* and save the results in *D:\RawData\OperationY\storageFacility.txt* with MS data ommited

`ScanHeadsman.exe D:\RawData\OperationY\storageFacility.raw D:\RawData\Police\coward.csv`

Process *D:\RawData\OperationY\storageFacility.raw* and save the results in *D:\RawData\Police\coward.csv* with MS data included